@@ -742,18 +742,27 @@ sim.popn <- function (D, core, buffer = 100, model2D = c("poisson",
                     if (nparent==0)
                         warning ("zero clusters")
                     parent <-  sweep(matrix(runif(2*nparent), ncol = 2), 2, c(xrange,yrange), '*')
-                    noffspr <- rpois(nparent, details$mu)
-                    N <- sum(noffspr) # nparent * details$mu
-                    offspr <- matrix(rnorm(2*N), ncol = 2) * details$hsigma
-                    parentn <- rep(1:nparent, noffspr)
-                    # parentn <- rep(1:nparent, details$mu)
-                    offspr <- offspr + parent[parentn,,drop = FALSE]
-                    while (any ((offspr[,1]<0) | (offspr[,1]>xrange) | (offspr[,2]<0) |
+                    if (!is.null(details$clone) && details$clone == 'constant') {
+                        # clone parent locations with no displacement 2023-05-03
+                        noffspr <- rep(details$mu, nparent)
+                        N <- sum(noffspr) 
+                        parentn <- rep(1:nparent, each = details$mu)
+                        offspr <- parent[parentn,,drop = FALSE]
+                    }
+                    else {
+                        noffspr <- rpois(nparent, details$mu)
+                        N <- sum(noffspr) # nparent * details$mu
+                        offspr <- matrix(rnorm(2*N), ncol = 2) * details$hsigma
+                        parentn <- rep(1:nparent, noffspr)
+                        # parentn <- rep(1:nparent, details$mu)
+                        offspr <- offspr + parent[parentn,,drop = FALSE]
+                        while (any ((offspr[,1]<0) | (offspr[,1]>xrange) | (offspr[,2]<0) |
                                 (offspr[,2]>yrange))) {
-                        offspr[,1] <- ifelse (offspr[,1]<0, offspr[,1]+xrange, offspr[,1])
-                        offspr[,1] <- ifelse (offspr[,1]>xrange, offspr[,1]-xrange, offspr[,1])
-                        offspr[,2] <- ifelse (offspr[,2]<0, offspr[,2]+yrange, offspr[,2])
-                        offspr[,2] <- ifelse (offspr[,2]>yrange, offspr[,2]-yrange, offspr[,2])
+                            offspr[,1] <- ifelse (offspr[,1]<0, offspr[,1]+xrange, offspr[,1])
+                            offspr[,1] <- ifelse (offspr[,1]>xrange, offspr[,1]-xrange, offspr[,1])
+                            offspr[,2] <- ifelse (offspr[,2]<0, offspr[,2]+yrange, offspr[,2])
+                            offspr[,2] <- ifelse (offspr[,2]>yrange, offspr[,2]-yrange, offspr[,2])
+                        }
                     }
                 }
                 animals <- as.data.frame(sweep(offspr,2,c(xl[1],yl[1]),'+'))
